#
# spec file for package perl-Carp-Assert-More
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Carp-Assert-More
Name:           perl-Carp-Assert-More
Version:        2.1.0
Release:        bp155.1.5
License:        Artistic-2.0
Summary:        Convenience assertions for common situations
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PE/PETDANCE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::Exception)
Requires:       perl(Test::Exception)
%{perl_requires}

%description
Carp::Assert::More is a convenient set of assertions to make the habit of
writing assertions even easier.

Everything in here is effectively syntactic sugar. There's no technical
difference between calling one of these functions:

    assert_datetime( $foo );
    assert_isa( $foo, 'DateTime' );

that are provided by Carp::Assert::More and calling these assertions from
Carp::Assert

    assert( defined $foo );
    assert( ref($foo) eq 'DateTime' );

My intent here is to make common assertions easy so that we as programmers
have no excuse to not use them.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md

%changelog
* Wed Aug 17 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.1.0
  see /usr/share/doc/packages/perl-Carp-Assert-More/Changes
  2.1.0   Mon Aug 15 19:54:27 CDT 2022
    [ENHANCEMENTS]
    Add diagnostic strings to the failures. For example:
    assert_nonblank( [ 'foo' ], 'This should be nonblank' );
    would fail with:
    Assertion (This should be nonblank) failed!
    but now fails with:
    Assertion (This should be nonblank) failed!
    Value is a reference to ARRAY.
    Similar changes have been made to:
  * assert_all_keys_in
  * assert_keys_are
  * assert_empty
  * assert_nonempty
* Sat Aug 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.0.1
  see /usr/share/doc/packages/perl-Carp-Assert-More/Changes
  2.0.1   Fri Aug 13 11:57:15 CDT 2021
    [FIXES]
    assert_all_keys_in() mistakenly required a non-empty list of
    keys to check.
    [ENHANCEMENTS]
    Sped up assert_isa_in(), assert_is().
  2.0.0   Thu Aug 12 23:00::00 CDT 2021
    [DIFFERENCES]
    Now requires Perl 5.10 or higher.  No longer requires Carp::Assert.
    The numeric functions are more stringent now.  If it expects
    a number, then you need to pass a number.  For example,
    assert_nonnegative($x) would pass if $x was a non-numeric
    string. Now it must be numeric.
    assert_empty() and assert_nonempty() no longer gives a message
    of "Not an array or hash reference".  If you don't pass an array
    or hash reference, the assertion will just fail with the message
    passe3d in.
    assert_aoh() and assert_datetime() no longer provide a default
    message.
    assert_in() is more strict. Each element of the target array
    is checked to not be a reference.
    assert_exists() and assert_lacks() are more strict.  The list
    of keys to check cannot be empty.
    [ENHANCEMENTS]
    Most of the functions are about twice as fast because of reduced
    number of function calls internally.
    Added assert_context_nonvoid() and assert_context_scalar()
    to assert on how the executing function has been called.
    assert_in() now lets you use undef as both the needle and one
    of the values in the haystack.
* Sun Dec 27 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.26
  see /usr/share/doc/packages/perl-Carp-Assert-More/Changes
  1.26    Sat Dec 26 00:26:23 CST 2020
    [ENHANCEMENTS]
    Add assert_arrayref_nonempty().
    Add assert_hashref_nonempty().
* Thu Oct  8 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.24
  see /usr/share/doc/packages/perl-Carp-Assert-More/Changes
  1.24    Tue Oct  6 22:37:06 CDT 2020
    [ENHANCEMENTS]
    The requirement for Perl 5.10 has been reverted to 5.6.1.
  1.22    Tue Oct  6 22:03:55 CDT 2020
    [ENHANCEMENTS]
    Add assert_keys_are() for asserting an exact list of keys.
* Sat Aug 10 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.20
  see /usr/share/doc/packages/perl-Carp-Assert-More/Changes
  1.20    Fri Aug  9 10:10:06 CDT 2019
    [ENHANCEMENTS]
    Add assert_datetime() for asserting DateTime objects.
* Sun Jul 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.18
  see /usr/share/doc/packages/perl-Carp-Assert-More/Changes
  1.18    Fri Jul 19 17:12:32 CDT 2019
    [ENHANCEMENTS]
    Added assert_aoh() for asserting an array of hashrefs.
* Sat Aug  5 2017 coolo@suse.com
- updated to 1.16
  see /usr/share/doc/packages/perl-Carp-Assert-More/Changes
  1.16    Fri Aug  4 14:18:51 CDT 2017
    [ENHANCEMENTS]
    Added the following functions:
  * assert_numeric( $n )
  * assert_all_keys_in( \%%hash, \@keylist )
  * assert_empty( [\%%hash|\@list] )
  * assert_coderef( $ref )
  * assert_isa_in( $ref, \@class_list )
    Thanks to Eric A. Zarko for some of them.  The rest were migrated
    from a private code project.
    Renamed assert_listref() to assert_arrayref(), but keep
    assert_listref() as backward compatibility.  assert_listref()
    may go away in the future.
    [DOCUMENTATION]
    Fixed a goof in the assert_integer() docs.  Thanks, Randy Lauen.
* Mon Jun  3 2013 coolo@suse.com
- updated to 1.14
    [ENHANCEMENTS]
    Added assert_undefined() for Ben Hengst.
    Added assert_unlike().
    [FIXES]
    assert_nonblank() wasn't using the correct message.  Thanks to
    Leland Johnson.
    assert_nonempty() wouldn't work on blessed arrays and refs.
    Now it will.
* Mon Jan 17 2011 coolo@novell.com
- initial package 1.12
  * created by cpanspec 1.78.03
